.. stream_tap documentation master file, created by
   sphinx-quickstart on Sun Mar 16 21:31:15 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to cooperative's documentation!
==========================================

Contents:

.. toctree::
   :maxdepth: 2

   getting-started
   source/cooperative
   source/cooperative.tests
   source/examples

Indices and tables
==================


* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

